@@ -14,6 +14,10 @@ png_path <- file.path(tempdir(), "frame%03d.png")
 png_files <- sprintf(png_path, 1:n)
 wonderland <- system.file('samples/Synapsis-Wonderland.mp3', package='av', mustWork = TRUE)
 
+# If libx264 is available, it is usually the default.
+# Note that it is not available for libavfilter-free-devel in Fedora
+has_libx264 <- "libx264" %in% av_muxers()$video
+
 test_that("convert images into video formats", {
   png(png_path, width = width, height = height, res = 72 * q)
   par(ask = FALSE)
@@ -25,11 +29,13 @@ test_that("convert images into video formats", {
     filename <- paste0("test.", ext)
     av::av_encode_video(png_files, filename, framerate = framerate, verbose = FALSE)
     expect_true(file.exists(filename))
-    info <- av_video_info(filename)
+    info <- av_media_info(filename)
 
     expect_equal(info$video$width, width)
     expect_equal(info$video$height, height)
-    expect_equal(info$video$codec, switch(ext, gif='gif', flv='flv', 'h264'))
+    if(has_libx264){
+      expect_equal(info$video$codec, switch(ext, gif='gif', flv='flv', 'h264'))
+    }
     expect_equal(info$video$framerate, framerate)
 
     # Gif doesn't have video metadata (duration)
@@ -38,7 +44,7 @@ test_that("convert images into video formats", {
 
       # Test converting video to video
       av_video_convert(filename, 'test2.mp4', verbose = FALSE)
-      info <- av_video_info('test2.mp4')
+      info <- av_media_info('test2.mp4')
       unlink('test2.mp4')
       expect_equal(info$video$width, width)
       expect_equal(info$video$height, height)
@@ -54,11 +60,13 @@ test_that("audio sampling works", {
     filename <- paste0("test.", ext)
     av::av_encode_video(png_files, filename, framerate = framerate, verbose = FALSE, audio = wonderland)
     expect_true(file.exists(filename))
-    info <- av_video_info(filename)
+    info <- av_media_info(filename)
 
     expect_equal(info$video$width, width)
     expect_equal(info$video$height, height)
-    expect_equal(info$video$codec, switch(ext, gif='gif', flv='flv', 'h264'))
+    if(has_libx264){
+      expect_equal(info$video$codec, switch(ext, flv='flv', 'h264'))
+    }
     expect_equal(info$video$framerate, framerate)
 
     expect_equal(info$audio$channels, 2)
@@ -69,7 +77,7 @@ test_that("audio sampling works", {
 
     # Test converting video to video
     av_video_convert(filename, 'test2.mp4', verbose = FALSE)
-    info <- av_video_info('test2.mp4')
+    info <- av_media_info('test2.mp4')
     unlink('test2.mp4')
     expect_equal(info$video$width, width)
     expect_equal(info$video$height, height)
@@ -89,7 +97,7 @@ test_that("audio sampling works", {
 test_that("fractional framerates work", {
   framerate <- 1/5
   av::av_encode_video(png_files, 'test.mp4', framerate = framerate, verbose = FALSE)
-  info <- av_video_info('test.mp4')
+  info <- av_media_info('test.mp4')
   unlink('test.mp4')
 
   expect_equal(info$video$framerate, framerate)
@@ -102,7 +110,7 @@ test_that("speed up/down filters", {
     framerate <- 25
     filter <- sprintf("setpts=%s*PTS", as.character(x))
     av::av_encode_video(png_files, 'speed.mp4', framerate = framerate, vfilter = filter, verbose = FALSE)
-    info <- av_video_info('speed.mp4')
+    info <- av_media_info('speed.mp4')
     unlink('speed.mp4')
     expect_equal(info$video$framerate, (framerate / x))
     expect_equal(info$duration, length(png_files) / (framerate / x))
@@ -127,9 +135,9 @@ test_that("test error handling", {
   expect_false(file.exists("video.mp4"))
 
   # Test time limit
-  setTimeLimit(elapsed = 2, transient = TRUE)
+  setTimeLimit(cpu = 2, transient = TRUE)
   timings <- system.time(expect_error(av_encode_video(rep(png_files, 100), verbose = FALSE), "time"))
   setTimeLimit()
-  expect_lt(timings[['elapsed']], 2.5)
+  expect_lt(timings[['sys.self']], 2.5)
   expect_equal(get_open_handles(), 0)
 })
